@@ -184,7 +184,7 @@ Ls.hmn = {
 	"ul_par": "parallel uploads:",
 	"ut_rand": "randomize filenames",
 	"ut_u2ts": "copy the last-modified timestamp$Nfrom your filesystem to the server\">📅",
-	"ut_ow": "overwrite existing files on the server?$N🛡️: never (will generate a new filename instead)$N🕒: overwrite if server-file is older than yours$N♻️: always overwrite if the files are different",
+	"ut_ow": "overwrite existing files on the server?$N🛡️: never (will generate a new filename instead)$N🕒: overwrite if server-file is older than yours$N♻️: always overwrite if the files are different$N⏭️: unconditionally skip all existing files",
 	"ut_mt": "continue hashing other files while uploading$N$Nmaybe disable if your CPU or HDD is a bottleneck",
 	"ut_ask": 'ask for confirmation before upload starts">💭',
 	"ut_pot": "improve upload speed on slow devices$Nby making the UI less complex",
@@ -249,11 +249,13 @@ Ls.hmn = {
 	"cl_reset": "reset",
 	"cl_hpick": "tap on column headers to hide in the table below",
 	"cl_hcancel": "column hiding aborted",
+	"cl_rcm": "right-click menu",
 
 	"ct_grid": '田 the grid',
 	"ct_ttips": '◔ ◡ ◔">ℹ️ tooltips',
 	"ct_thumb": 'in grid-view, toggle icons or thumbnails$NHotkey: T">🖼️ thumbs',
 	"ct_csel": 'use CTRL and SHIFT for file selection in grid-view">sel',
+	"ct_dsel": 'use drag-selection in grid-view">dsel',
 	"ct_dl": 'force download (don\'t display inline) when a file is clicked">dl',
 	"ct_ihop": 'when the image viewer is closed, scroll down to the last viewed file">g⮯',
 	"ct_dots": 'show hidden files (if server permits)">dotfiles',
@@ -291,6 +293,8 @@ Ls.hmn = {
 	"cdt_lim": "max number of files to show in a folder",
 	"cdt_ask": "when scrolling to the bottom,$Ninstead of loading more files,$Nask what to do",
 	"cdt_hsort": "how many sorting rules (&lt;code&gt;,sorthref&lt;/code&gt;) to include in media-URLs. Setting this to 0 will also ignore sorting-rules included in media links when clicking them",
+	"cdt_ren": "enable custom right-click menu, you can still access the regular menu by pressing the shift key and right-clicking",
+	"cdt_rdb": "show the regular right-click menu when the custom one is already open and right-clicking again",
 
 	"tt_entree": "show navpane (directory tree sidebar)$NHotkey: B",
 	"tt_detree": "show breadcrumbs$NHotkey: B",
@@ -361,6 +365,7 @@ Ls.hmn = {
 	"mm_eunk": "Unknown Errol",
 	"mm_e404": "Could not play audio; error 404: File not found.",
 	"mm_e403": "Could not play audio; error 403: Access denied.\n\nTry pressing F5 to reload, maybe you got logged out",
+	"mm_e415": "Could not play audio; error 415: File transcoding failed; check server logs.",
 	"mm_e500": "Could not play audio; error 500: Check server logs.",
 	"mm_e5xx": "Could not play audio; server error ",
 	"mm_nof": "not finding any more audio files nearby",
@@ -380,6 +385,7 @@ Ls.hmn = {
 	"f_anota": "only {0} of the {1} items were selected;\nto select the full folder, first scroll to the bottom",
 
 	"f_dls": 'the file links in the current folder have\nbeen changed into download links',
+	"f_dl_nd": 'skipping folder (use zip/tar download instead):\n',
 
 	"f_partial": "To safely download a file which is currently being uploaded, please click the file which has the same filename, but without the <code>.PARTIAL</code> file extension. Please press CANCEL or Escape to do this.\n\nPressing OK / Enter will ignore this warning and continue downloading the <code>.PARTIAL</code> scratchfile instead, which will almost definitely give you corrupted data.",
 
@@ -448,9 +454,10 @@ Ls.hmn = {
 	"fcc_warn": 'copied {0} items to clipboard\n\nbut: only <b>this</b> browser-tab can paste them\n(since the selection is so absolutely massive)',
 
 	"fp_apply": "use these names",
+	"fp_skip": "skip conflicts",  // TLNote: "skip existing names" (filenames taken in target folder)
 	"fp_ecut": "first cut or copy some files / folders to paste / move\n\nnote: you can cut / paste across different browser tabs",
-	"fp_ename": "{0} items cannot be moved here because the names are already taken. Give them new names below to continue, or blank the name to skip them:",
-	"fcp_ename": "{0} items cannot be copied here because the names are already taken. Give them new names below to continue, or blank the name to skip them:",
+	"fp_ename": "{0} items cannot be moved here because the names are already taken. Give them new names below to continue, or blank the name (\"skip conflicts\") to skip them:",
+	"fcp_ename": "{0} items cannot be copied here because the names are already taken. Give them new names below to continue, or blank the name (\"skip conflicts\") to skip them:",
 	"fp_emore": "there are still some filename collisions left to fix",
 	"fp_ok": "move OK",
 	"fcp_ok": "copy OK",
@@ -666,6 +673,26 @@ Ls.hmn = {
 	"ur_um": "Finished;\n{0} uploads OK,\n{1} uploads failed, sorry",
 	"ur_sm": "Finished;\n{0} files found on server,\n{1} files NOT found on server",
 
+	"rc_opn": "open",
+	"rc_ply": "play",
+	"rc_pla": "play as audio",
+	"rc_txt": "open in textfile viewer",
+	"rc_md": "open in markdown viewer",
+	"rc_dl": "download",
+	"rc_zip": "download as archive",
+	"rc_cpl": "copy link",
+	"rc_del": "delete",
+	"rc_cut": "cut",
+	"rc_cpy": "copy",
+	"rc_pst": "paste",
+	"rc_rnm": "rename",
+	"rc_nfo": "new folder",
+	"rc_nfi": "new file",
+	"rc_sal": "select all",
+	"rc_sin": "invert selection",
+	"rc_shf": "share this folder",
+	"rc_shs": "share selection",
+
 	"lang_set": "refresh to make the change take effect?",
 
 	"splash": {
@@ -684,6 +711,11 @@ Ls.hmn = {
 		"j1": "enabling k304 will disconnect your client on every HTTP 304, which can prevent some buggy proxies from getting stuck (suddenly not loading pages), <em>but</em> it will also make things slower in general",
 		"k1": "reset client settings",
 		"l1": "login for more:",
+		"ls3": "login",
+		"lu4": "username",
+		"lp4": "password",
+		"lo3": "logout “{0}” everywhere",
+		"lo2": "ends the session on all browsers",
 		"m1": "welcome back,",  // TLNote: "welcome back, USERNAME"
 		"n1": "404 not found &nbsp;┐( ´ -`)┌",
 		"o1": 'or maybe you don\'t have access -- try a password or <a href="' + SR + '/?h">go home</a>',
@@ -710,5 +742,6 @@ Ls.hmn = {
 		"ad1": "enabling no304 will disable all caching; try this if k304 wasn't enough. This will waste a huge amount of network traffic!",
 		"ae1": "active downloads:",
 		"af1": "show recent uploads",
+		"ag1": "view idp cache",  // TLNote: is a link to a page where IdP users can be managed
 	}
 };
