@@ -187,9 +187,9 @@ class TestVFS(unittest.TestCase):
         self.assertEqual(n.realpath, os.path.join(td, "a"))
         self.assertAxs(n.axs.uread, ["*", "k"])
         self.assertAxs(n.axs.uwrite, [])
-        perm_na = (False, False, False, False, False, False, False, False)
-        perm_rw = (True, True, False, False, False, False, False, False)
-        perm_ro = (True, False, False, False, False, False, False, False)
+        perm_na = (False, False, False, False, False, False, False, False, False)
+        perm_rw = (True, True, False, False, False, False, False, False, False)
+        perm_ro = (True, False, False, False, False, False, False, False, False)
         self.assertEqual(vfs.can_access("/", "*"), perm_na)
         self.assertEqual(vfs.can_access("/", "k"), perm_rw)
         self.assertEqual(vfs.can_access("/a", "*"), perm_ro)
